sagace.auth package — sagace 2025 documentation

# sagace.auth package

## Subpackages

- sagace.auth.application package
  - Submodules
  - sagace.auth.application.authentication_use_case module
    - Descrição:
    - `AuthenticateUser`
      - `AuthenticateUser.execute()`
  - Module contents
    - Description:
- sagace.auth.domain package
  - Submodules
  - sagace.auth.domain.authentication_repository module
    - Descrição:
    - `AuthenticationRepository`
      - `AuthenticationRepository._abc_impl`
      - `AuthenticationRepository.authenticate()`
  - Module contents
    - Description:
- sagace.auth.infrastructure package
  - Submodules
  - sagace.auth.infrastructure.authentication_api module
    - Descrição:
    - `AuthenticationAPI`
      - `AuthenticationAPI.AUTH_URL`
      - `AuthenticationAPI.BASE_URL`
      - `AuthenticationAPI._abc_impl`
      - `AuthenticationAPI.authenticate()`
  - Module contents
    - Description:
- sagace.auth.interfaces package
  - Submodules
  - sagace.auth.interfaces.authentication_service module
    - Descrição:
    - `AuthenticationService`
      - `AuthenticationService.login()`
  - Module contents
    - Description:

## Module contents

### Description:

Obs.:

Author: @diego.yosiura Last Update: 27/02/2025 15:29 Created: 27/02/2025 15:29 Copyright: (c) Ampere Consultoria Ltda Original Project: sagace-v2-package IDE: PyCharm